import java.awt.Container;
import java.awt.GridLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JOptionPane;
import javax.swing.JTextArea;

/**
 * Diese Klasse repräsentiert das Hauptfenster der Hausaufgabe zur Berechnung
 * der Summe aller geraden Zahlen mittels Modulo.
 * 
 * @author Annabelle Klarl
 * 
 */
public class ModuloFrame extends JFrame implements ActionListener {
	private JButton geradezahlenButton;

	private JTextArea ausgabeBereich;

	/**
	 * In diesem Programmstück wird das Fenster erzeugt
	 */
	public ModuloFrame() {
		/* In der Kopfleiste des Fenster steht "ModuloFrame" */
		this.setTitle("ModuloFrame");

		/* Das Fenster ist 500 Pixel breit und 200 Pixel hoch. */
		this.setSize(500, 200);

		/* Hier werden alle Buttons erzeugt. */
		this.geradezahlenButton = new JButton(
				"Summe gerader Zahlen eines Arrays berechnen");

		/* Hier wird der Ausgabe-Bereich erzeugt. */
		this.ausgabeBereich = new JTextArea(10, 100);

		/*
		 * Der ContentPane ist der Ausschnitt des Fensters, auf dem Widgets d.h.
		 * Interaktionselemente (wie eine TextArea oder ein Button) platziert
		 * werden können.
		 */
		Container contentPane = this.getContentPane();
		contentPane.setLayout(new GridLayout(2, 1));
		/* Hier wird der Button platziert. */
		contentPane.add(this.geradezahlenButton);
		/* Hier wird der Ausgabebereich platziert. */
		contentPane.add(this.ausgabeBereich);

		/*
		 * Hier wird der ModuloFrame als Listener für Knopfdruck-Ereignisse bei
		 * jedem der Buttons registriert.
		 */
		this.geradezahlenButton.addActionListener(this);

		/*
		 * Wird das Fenster geschlossen (d.h. auf X gedrückt), wird mit Hilfe
		 * dieser Programmzeile auch unser Programm ordnungsgemäß beendet.
		 */
		this.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
	}

	@Override
	public void actionPerformed(ActionEvent e) {
		// je nach Button entsprechende Methode ausführen
		Object source = e.getSource();
		if (source == this.geradezahlenButton) {
			this.summeBerechnen();
		}
	}

	/**
	 * implementiert die Funktionalität des
	 * "Summe gerader Zahlen berechnen"-Buttons
	 */
	public void summeBerechnen() {
		String einlesenArray = JOptionPane.showInputDialog("Array eingeben: ");
		int[] arr = Konverter.konvertiereZuIntArray(einlesenArray);

		int sum = 0;
		try {
			sum = this.summeGeraderZahlen(arr);
			this.ausgabeBereich.setText("Summe = " + sum);
		} catch (NegativeElementException e) {
			this.ausgabeBereich.setText("Fehler!");
		}

	}

	/**
	 * berechnet die Summe aller geraden Zahlen
	 * 
	 * @param arr
	 * 
	 * @return Summe der geraden Zahlen
	 */
	public int summeGeraderZahlen(int[] arr) throws NegativeElementException {
		int sum = 0;

		for (int i = 0; i < arr.length; i++) {
			if (arr[i] < 0) {
				throw new NegativeElementException();
			}
			if (arr[i] % 2 == 0) {
				sum = sum + arr[i];
			}
		}
		return sum;
	}
}
